==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkLabelHierarchyAlgorithm.java <==
// java wrapper for vtkLabelHierarchyAlgorithm object
//

package vtk;
import vtk.*;

public class vtkLabelHierarchyAlgorithm extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkLabelHierarchy GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkLabelHierarchy GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutput_4(vtkDataObject id0);
  public void SetOutput(vtkDataObject id0)
    { SetOutput_4(id0); }

  private native long GetInput_5();
  public vtkDataObject GetInput() {
    long temp = GetInput_5();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_6(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLabelHierarchyInput_7(int id0);
  public vtkLabelHierarchy GetLabelHierarchyInput(int id0) {
    long temp = GetLabelHierarchyInput_7(id0);

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputData_8(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_8(id0); }

  private native void SetInputData_9(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_9(id0,id1); }

  private native void AddInputData_10(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_10(id0); }

  private native void AddInputData_11(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_11(id0,id1); }

  public vtkLabelHierarchyAlgorithm() { super(); }

  public vtkLabelHierarchyAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkLabelHierarchyAlgorithm.java <==
// java wrapper for vtkLabelHierarchyAlgorithm object
//

package vtk;
import vtk.*;

public class vtkLabelHierarchyAlgorithm extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkLabelHierarchy GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkLabelHierarchy GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutput_4(vtkDataObject id0);
  public void SetOutput(vtkDataObject id0)
    { SetOutput_4(id0); }

  private native long GetInput_5();
  public vtkDataObject GetInput() {
    long temp = GetInput_5();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_6(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLabelHierarchyInput_7(int id0);
  public vtkLabelHierarchy GetLabelHierarchyInput(int id0) {
    long temp = GetLabelHierarchyInput_7(id0);

    if (temp == 0) return null;
    return (vtkLabelHierarchy)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputData_8(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_8(id0); }

  private native void SetInputData_9(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_9(id0,id1); }

  private native void AddInputData_10(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_10(id0); }

  private native void AddInputData_11(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_11(id0,id1); }

  public vtkLabelHierarchyAlgorithm() { super(); }

  public vtkLabelHierarchyAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}
